<?php
namespace FoodExpo\Widgets;
 /**
  * 
  * @package    FoodExpo
  * @version    1.0
  * @author     WPBucket
  * @Websites: http://wpbucket.net
  *
  */

if( !defined( 'WPINC' ) ){
    die;
}
// Make sure the same class is not loaded twice in free/premium versions.
if ( !class_exists( 'FoodExpo_El_Widgets' ) ) {
    /**
     * Main FoodExpo Elementor Widgets Class
     *
     *
     * @since 1.7.0
     */
    final class FoodExpo_El_Widgets {
        /**
         *
         * Holds the version of the plugin.
         *
         * @since 1.7.0
         * @since 1.7.1 Moved from property with that name to a constant.
         *
         * @var string The plugin version.
         */
        const  VERSION = '1.0' ;
        /**
         * Minimum Elementor Version
         *
         * Holds the minimum Elementor version required to run the plugin.
         *
         * @since 1.7.0
         * @since 1.7.1 Moved from property with that name to a constant.
         *
         * @var string Minimum Elementor version required to run the plugin.
         */
        const  MINIMUM_ELEMENTOR_VERSION = '1.7.0';
        /**
         * Minimum PHP Version
         *
         * Holds the minimum PHP version required to run the plugin.
         *
         * @since 1.7.0
         * @since 1.7.1 Moved from property with that name to a constant.
         *
         * @var string Minimum PHP version required to run the plugin.
         */
        const  MINIMUM_PHP_VERSION = '7.0' ;
        /**
         * Instance
         *
         * Holds a single instance of the `Press_Elements` class.
         *
         * @since 1.7.0
         *
         * @access private
         * @static
         *
         * @var Press_Elements A single instance of the class.
         */
        private static  $_instance = null ;

        /**
         * Instance
         *
         * Ensures only one instance of the class is loaded or can be loaded.
         *
         * @since 1.7.0
         *
         * @access public
         * @static
         *
         * @return Press_Elements An instance of the class.
         */
        public static function instance() {
            if ( is_null( self::$_instance ) ) {
                self::$_instance = new self();
            }
            return self::$_instance;
        }

        /**
         * Clone
         *
         * Disable class cloning.
         *
         * @since 1.7.0
         *
         * @access protected
         *
         * @return void
         */
        public function __clone() {
            // Cloning instances of the class is forbidden
            _doing_it_wrong( __FUNCTION__, esc_html__( 'Cheatin&#8217; huh?', 'foodexpo' ), '1.7.0' );
        }

        /**
         * Wakeup
         *
         * Disable unserializing the class.
         *
         * @since 1.7.0
         *
         * @access protected
         *
         * @return void
         */
        public function __wakeup() {
            // Unserializing instances of the class is forbidden.
            _doing_it_wrong( __FUNCTION__, esc_html__( 'Cheatin&#8217; huh?', 'foodexpo' ), '1.7.0' );
        }

        /**
         * Constructor
         *
         * Initialize the elementor widgets.
         *
         * @since 1.7.0
         *
         * @access public
         */
        public function __construct() {
            $this->init_hooks();
        }


        /**
         * Init Hooks
         *
         * Hook into actions and filters.
         *
         * @since 1.7.0
         *
         * @access private
         */
        private function init_hooks() {
            $this->init();
        }


        /**
         * Init Elementor Widget
         *
         * Load the plugin after Elementor (and other plugins) are loaded.
         *
         * @since 1.0.0
         * @since 1.7.0 The logic moved from a standalone function to this class method.
         *
         * @access public
         */
        public function init() {

            // Check for required Elementor version
            if ( !version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
                add_action( 'admin_notices', [ $this, 'admin_notice_minimum_elementor_version' ] );
                return;
            }

            // Check for required PHP version

            if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
                add_action( 'admin_notices', [ $this, 'admin_notice_minimum_php_version' ] );
                return;
            }
            // Add new Elementor Categories
            add_action( 'elementor/elements/categories_registered', [ $this, 'add_elementor_category' ] );
            // Register New Widgets
            add_action( 'elementor/widgets/widgets_registered', [ $this, 'on_widgets_registered' ] );

            // enqueue style and scripts
            add_action( 'wp_enqueue_scripts', [ $this, 'enqueue_element_widgets_scripts' ] );

        }

        /**
         * Admin notice
         *
         * Warning when the site doesn't have Elementor installed or activated.
         *
         * @since 1.1.0
         * @since 1.7.0 Moved from a standalone function to a class method.
         *
         * @access public
         */
        public function admin_notice_missing_main_plugin() {
            $message = sprintf(
            /* translators: 1: Elementor */
                esc_html__( '"%1$s" requires "%2$s" to be installed and activated.', 'foodexpo' ),
                '<strong>' . esc_html__( 'FoodExpo WordPress Plugin', 'foodexpo' ) . '</strong>',
                '<strong>' . esc_html__( 'Elementor', 'foodexpo' ) . '</strong>'
            );
            printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
        }

        /**
         * Admin notice
         *
         * Warning when the site doesn't have a minimum required Elementor version.
         *
         * @since 1.1.0
         * @since 1.7.0 Moved from a standalone function to a class method.
         *
         * @access public
         */
        public function admin_notice_minimum_elementor_version() {
            $message = sprintf(
            /* translators: 1: Elementor 2: Required Elementor version */
                esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'foodexpo' ),
                '<strong>' . esc_html__( 'FoodExpo', 'foodexpo' ) . '</strong>',
                '<strong>' . esc_html__( 'Elementor', 'foodexpo' ) . '</strong>',
                self::MINIMUM_ELEMENTOR_VERSION
            );
            printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
        }

        /**
         * Admin notice
         *
         * Warning when the site doesn't have a minimum required PHP version.
         *
         * @access public
         */
        public function admin_notice_minimum_php_version() {
            $message = sprintf(
            /* translators: 1: PHP 2: Required PHP version */
                esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'foodexpo' ),
                '<strong>' . esc_html__( 'FoodExpo', 'foodexpo' ) . '</strong>',
                '<strong>' . esc_html__( 'PHP', 'foodexpo' ) . '</strong>',
                self::MINIMUM_PHP_VERSION
            );
            printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
        }

        /**
         * Add new Elementor Categories
         *
         * Register new widget categories for FoodExpo widgets.
         *
         * @access public
         */
        public function add_elementor_category() {

            \Elementor\Plugin::instance()->elements_manager->add_category( 'foodexpo-elements', [
                'title' => esc_html__( 'FoodExpo', 'foodexpo' ),
            ], 1 );

        }

        /**
         * Enqueue Widgets Scripts
         *
         * Enqueue custom scripts required to run elementor widgets.
         *
         * @access public
         */
        public function enqueue_element_widgets_scripts() {

            wp_enqueue_style( 'carousel', FOODEXPO_DIR_URL.'assets/css/owl.carousel.min.css', array(), '1.0', false );
            wp_enqueue_style( 'carousel-theme-default', FOODEXPO_DIR_URL.'assets/css/owl.theme.default.min.css', array(), '1.0', false );
            wp_enqueue_style( 'foodexpo-style', FOODEXPO_DIR_URL.'assets/css/style.css', array(), '1.0', false );
            
            /********************
                Js Enqueue
            ********************/

            wp_enqueue_script( 'carousel', FOODEXPO_DIR_URL.'assets/js/owl.carousel.min.js', array('jquery'), '1.0.0', true );
            wp_enqueue_script( 'foodexpo-main', FOODEXPO_DIR_URL.'assets/js/main.js', array('jquery'), '1.0.0', true );
            
        }

        

        /**
         * Register New Widgets
         *
         * Include widgets files and register them in Elementor.
         *
         * @since 1.0.0
         * @since 1.7.1 The method moved to this class.
         *
         * @access public
         */
        public function on_widgets_registered() {
            
            //
            $widgets = new Widgets_List();

            $activeWidget = get_option( FoodExpo_OPTION_NAME );

            if( !empty( $activeWidget  ) ) {
                foreach( $widgets->widgets_map() as $widget ) {

                    if( !empty( $widget['name'] ) && in_array( $widget['name'], $activeWidget  ) ) {

                        $widgetName = $widget['name'];

                        $prepareName = $this->class_name_prepare( $widgetName );

                        $file = FOODEXPO_EW_DIR_PATH . 'widgets/'.$prepareName.'.php';

                        if( is_readable( $file ) ) {

                            require_once( $file );

                            $className = '\FoodExpo\Widgets\\'.$prepareName;

                            if( class_exists( $className ) ) {
                                
                                \Elementor\Plugin::instance()->widgets_manager->register(  new $className );
                            }

                        }


                    }
                }
            }

        }


    /**
     * Class name prepare
     * From widgets list
     *
     * @since 1.0.0
     *
     * @access public
     */
    public function class_name_prepare( $name ) {

        $newName = str_replace( ' ', '_', $name );
        return str_replace( ['-', ' '], '_',  ucwords( $newName, '_' ) );

    }


    }
}


/**
 * Load FoodExpo elementor widget
 */

FoodExpo_El_Widgets::instance();



add_action( 'wp_enqueue_scripts', function() {
    wp_dequeue_style('elementor-global');
});